@@ -1,11 +1,12 @@
 #!/usr/bin/perl
 
 use strict;
-use Cisco::Management;
-use blib;
+use warnings;
 use Getopt::Long qw(:config no_ignore_case); #bundling
 use Pod::Usage;
 
+use Cisco::Management;
+
 my %opt;
 my ($opt_help, $opt_man);
 
