@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use Exporter;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Sys::Hostname;
 use Socket qw(inet_ntoa AF_INET IPPROTO_TCP);
@@ -2034,18 +2034,15 @@ Cisco::Management - Interface for Cisco Management
 
 =head1 DESCRIPTION
 
+This module is deprecated - please use L<Cisco::SNMP>.
+
 B<Cisco::Management> is a class implementing several management functions
 for Cisco devices - mostly via SNMP.  B<Cisco::Management> uses the
 B<Net::SNMP> module to do the SNMP calls.
 
 =head1 CAVEATS
 
-Version 0.08 will the last in this line of support.  The next version
-will be a complete rewrite separating functions into sub classes allowing
-for quicker and easier development as well as allowing others to
-contribute to the Cisco::Management package.  For the most part, the
-initial release will be 99% backward compatible with several warnings
-for deprecated calls that should be updated to the new API.
+This module is deprecated - please use L<Cisco::SNMP>.
 
 As of version 0.06, B<Cisco::Management> supports IPv6 on systems with IPv6
 configured but requires B<Socket> version 1.94 or greater.  This may cause
@@ -2771,6 +2768,10 @@ This distribution comes with several scripts (installed to the default
 C<bin> install directory) that not only demonstrate example uses but also
 provide functional execution.
 
+=head1 SEE ALSO
+
+L<Cisco::SNMP>
+
 =head1 LICENSE
 
 This software is released under the same terms as Perl itself.
